%global realname gproc
#
# This package contains only arch-independent data but install it into
# arch-dependent directory thus making this package arch-dependent. In order to
# suppress empty *-debuginfo generation we have to explicitly order
# debuginfo-generator to skip trying to build *-debuiginfo for that package.
#
%global debug_package %{nil}


Name:		erlang-%{realname}
Version:	0.2.17
Release:	3%{?dist}
Summary:	Extended process registry for Erlang
Group:		Development/Libraries
License:	ERPL
URL:		https://github.com/uwiger/gproc
%if 0%{?fedora}
VCS:		https://github.com/uwiger/gproc.git
%endif
Source0:	https://github.com/uwiger/gproc/archive/%{version}/%{realname}-%{version}.tar.gz
# Fedora/EPEL-specific
Patch1:		erlang-gproc-0001-Proper-version-in-.app.patch
# Backported from upstream
Patch2:		erlang-gproc-0002-gproc_dist-would-crash-in-surrender.patch
# Backported from upstream
Patch3:		erlang-gproc-0003-gproc_dist-set_value_shared-2.patch
BuildRequires:	erlang-edown
BuildRequires:	erlang-gen_leader
BuildRequires:	erlang-rebar
Requires:	erlang-crypto%{?_isa}
# Error:erlang(erlang:min/2) in R12B and below
# Error:erlang(ets:give_away/3) in R12B and below
# Error:erlang(lists:keyfind/3) in R12B and below
Requires:	erlang-erts%{?_isa} >= R13B
Requires:	erlang-gen_leader%{?_isa}
Requires:	erlang-kernel%{?_isa}
Requires:	erlang-mnesia%{?_isa}
Requires:	erlang-stdlib%{?_isa} >= R12B-5


%description
Extended process registry for Erlang.


%prep
%setup -q -n %{realname}-%{version}
%patch1 -p1 -b .fix_version
%patch2 -p1 -b .fix_failure
%patch3 -p1 -b .add_missing_function


%build
rebar compile -v
#rebar doc -v


%install
mkdir -p %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/ebin
mkdir -p %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/include
mkdir -p %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/priv
install -m 644 ebin/%{realname}.app %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/ebin
install -m 644 ebin/%{realname}*.beam %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/ebin
install -m 644 include/%{realname}.hrl %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/include
install -m 644 priv/sys.config %{buildroot}%{_libdir}/erlang/lib/%{realname}-%{version}/priv
# Remove edoc config files (not needed for end-users)
rm -f doc/edoc-info
rm -f doc/overview.edoc
rm -f doc/README.md


%check
rebar eunit skip_deps=true -v


%files
%doc doc/* LICENSE README.md
%dir %{_libdir}/erlang/lib/%{realname}-%{version}
%dir %{_libdir}/erlang/lib/%{realname}-%{version}/ebin
%dir %{_libdir}/erlang/lib/%{realname}-%{version}/include
%dir %{_libdir}/erlang/lib/%{realname}-%{version}/priv
%{_libdir}/erlang/lib/%{realname}-%{version}/ebin/%{realname}.app
%{_libdir}/erlang/lib/%{realname}-%{version}/ebin/*.beam
%{_libdir}/erlang/lib/%{realname}-%{version}/include/*.hrl
%{_libdir}/erlang/lib/%{realname}-%{version}/priv/sys.config


%changelog
* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.17-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Aug 14 2013 Peter Lemenkov <lemenkov@gmail.com> - 0.2.17-2
- Added missing gproc_dist:set_value_shared/2 - https://github.com/uwiger/gproc/issues/46

* Mon Aug 12 2013 Peter Lemenkov <lemenkov@gmail.com> - 0.2.17-1
- Ver. 0.2.17

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Mar 06 2013 Peter Lemenkov <lemenkov@gmail.com> - 0.2.16-1
- Ver. 0.2.16
- Drop upstreamed patches

* Sun Mar 03 2013 Peter Lemenkov <lemenkov@gmail.com> - 0.2.15-2
- Fix doc installation

* Sat Mar 02 2013 Peter Lemenkov <lemenkov@gmail.com> - 0.2.15-1
- Ver. 0.2.15
- Drop R12B (EL5) compatibility patches

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Dec 21 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.14-1
- Ver. 0.2.14 (API/ABI compatible release)

* Thu Oct 11 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.13.3-1
- Ver. 0.2.13.3

* Sun Jul 29 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.13-1
- Ver. 0.2.13

* Sat Jul 28 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.11-4
- Another bunch of fixes for R12B

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 31 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.11-2
- Allow build on EL5

* Tue May 15 2012 Peter Lemenkov <lemenkov@gmail.com> - 0.2.11-1
- Ver. 0.2.11 (fixes rhbz #824342)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.5.20100929gitf0807c9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.4.20100929gitf0807c9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Nov 25 2010 Peter Lemenkov <lemenkov@gmail.com> - 0-0.3.20100929gitf0807c9
- Fixed License tag
- Removed uit-tests which requires proprietary testing software framework

* Wed Nov 10 2010 Peter Lemenkov <lemenkov@gmail.com> - 0-0.2.20100929gitf0807c9
- Use system-wide rebar
- Don't run make eunit twice

* Wed Sep 29 2010 Peter Lemenkov <lemenkov@gmail.com> - 0-0.1.20100929gitf0807c9
- Initial build

